==> 3.2.0.tar.gz: test/method_call_handler/on_success_test.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:nevis_mobile_authentication_sdk_ios/nevis_mobile_authentication_sdk_ios.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

import '../mocks/method_channel_test_shared_mocks.mocks.dart';
import '../test_data/authorization_provider_test_data.dart';
import '../test_data/common_test_data.dart';
import '../test_data/on_success_test_data.dart';
import '../util/ios_test_init.dart';
import '../util/method_channel_native_call_mock.dart';

void main() {
  IosTestInit.initIosTestCase();

  group(NevisMobileAuthenticationSdkIos, () {
    const MethodChannel channel = MethodChannel(
      CommonTestData.methodChannelName,
    );

    group("Given onSuccess is called from the native side", () {
      const methodName = 'onSuccess';
      late MockMethodChannelMethodCallCache mockCache;
      group("When the incoming parameters are correct", () {
        setUp(() async {
          mockCache = MockMethodChannelMethodCallCache();
          NevisMobileAuthenticationSdkIos.mock(
              MethodChannelMethodCallHandler.mock(mockCache));
        });

        tearDown(() async {
          channel.setMockMethodCallHandler(null);
        });

        test("Then the call is propagated to the cached delegate.", () async {
          final operation = MockOutOfBandPlatformOperation();
          final operationId = CommonTestData.operationId;
          when(mockCache.getOperation(operationId)).thenReturn(operation);
          when(mockCache.removeOperation(operationId)).thenReturn(null);
          when(operation.onSuccess(any)).thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            OnSuccessTestData.correctArguments,
          );

          verifyInOrder([
            mockCache.getOperation(operationId),
            operation.onSuccess(argThat(isNull)),
            mockCache.removeOperation(operationId)
          ]);
        });

        test(
            "Then the call is propagated to the cached delegate and a Cookie authorization provider is created.",
            () async {
          final operation = MockOutOfBandAuthenticationPlatformOperation();
          final operationId = CommonTestData.operationId;
          when(mockCache.getOperation(operationId)).thenReturn(operation);
          when(mockCache.removeOperation(operationId)).thenReturn(null);
          when(operation.onSuccess(any)).thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            OnSuccessTestData.correctArgumentsWithCookieProvider,
          );

          verify(mockCache.getOperation(operationId));
          var captured =
              verify(operation.onSuccess(captureAny)).captured.single;
          if (captured is CookieAuthorizationProvider) {
            final cookieContainer = captured.cookieContainers.first;
            expect(
              cookieContainer.cookie,
              AuthorizationProviderTestData.cookieString,
            );
          } else {
            throw Exception("Authorization provider has wrong type!");
          }

          verify(mockCache.removeOperation(operationId));
        });

        test(
            "Then the call is propagated to the cached delegate and a JWT authorization provider is created.",
            () async {
          final operation = MockOutOfBandAuthenticationPlatformOperation();
          final operationId = CommonTestData.operationId;
          when(mockCache.getOperation(operationId)).thenReturn(operation);
          when(mockCache.removeOperation(operationId)).thenReturn(null);
          when(operation.onSuccess(any)).thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            OnSuccessTestData.correctArgumentsWithJwtProvider,
          );

          verify(mockCache.getOperation(operationId));
          var captured =
              verify(operation.onSuccess(captureAny)).captured.single;
          if (captured is JwtAuthorizationProvider) {
            expect(captured.jwt, AuthorizationProviderTestData.jwt);
          } else {
            throw Exception("Authorization provider has wrong type!");
          }

          verify(mockCache.removeOperation(operationId));
        });
      });

      group("When the operationId is missing", () {
        setUp(() async {
          mockCache = MockMethodChannelMethodCallCache();
          NevisMobileAuthenticationSdkIos.mock(
              MethodChannelMethodCallHandler.mock(mockCache));
        });

        tearDown(() async {
          channel.setMockMethodCallHandler(null);
        });

        test("Then PlatformChannelException is thrown", () async {
          final operationId = CommonTestData.wrongId;
          when(mockCache.getOperation(operationId)).thenThrow(
              PlatformChannelException(
                  error: PlatformChannelError.noOperationFoundError(
                      operationId: operationId)));

          try {
            await channel.invokeMockMethod(
              methodName,
              OnSuccessTestData.wrongArguments,
            );
            fail('PlatformChannelException expected');
          } on PlatformException catch (e) {
            expect(
              e.message,
              CommonTestData.platformChannelExceptionMatcher,
            );
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verify(mockCache.getOperation(operationId));
        });
      });
    });
  });
}

==> 3.4.0.tar.gz: test/method_call_handler/on_success_test.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:nevis_mobile_authentication_sdk_ios/nevis_mobile_authentication_sdk_ios.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

import '../mocks/method_channel_test_shared_mocks.mocks.dart';
import '../test_data/authorization_provider_test_data.dart';
import '../test_data/common_test_data.dart';
import '../test_data/on_success_test_data.dart';
import '../util/ios_test_init.dart';
import '../util/method_channel_native_call_mock.dart';

void main() {
  IosTestInit.initIosTestCase();

  group(NevisMobileAuthenticationSdkIos, () {
    late MethodChannel channel;
    late MockMethodChannelMethodCallCache cache;
    const methodName = 'onSuccess';

    setUp(() {
      cache = MockMethodChannelMethodCallCache();
      NevisMobileAuthenticationSdkIos.mock(
          MethodChannelMethodCallHandler.mock(cache));
      channel = const MethodChannel(
        CommonTestData.methodChannelName,
      );
    });

    tearDown(() {
      channel.setMockMethodCallHandler(null);
      resetMockitoState();
    });

    group("Given $methodName is called from the native side", () {
      group("When the incoming parameters are correct", () {
        test("Then the call is propagated to the cached delegate.", () async {
          final operation = MockOutOfBandPlatformOperation();
          final operationId = CommonTestData.operationId;
          when(cache.getOperation(operationId)).thenReturn(operation);
          when(cache.removeOperation(operationId)).thenReturn(null);
          when(operation.onSuccess(any)).thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            OnSuccessTestData.correctArguments,
          );

          verifyInOrder([
            cache.getOperation(operationId),
            operation.onSuccess(argThat(isNull)),
            cache.removeOperation(operationId)
          ]);
        });

        test(
            "Then the call is propagated to the cached delegate and a Cookie authorization provider is created.",
            () async {
          final operation = MockOutOfBandAuthenticationPlatformOperation();
          final operationId = CommonTestData.operationId;
          when(cache.getOperation(operationId)).thenReturn(operation);
          when(cache.removeOperation(operationId)).thenReturn(null);
          when(operation.onSuccess(any)).thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            OnSuccessTestData.correctArgumentsWithCookieProvider,
          );

          verify(cache.getOperation(operationId));
          var captured =
              verify(operation.onSuccess(captureAny)).captured.single;
          if (captured is CookieAuthorizationProvider) {
            final cookieContainer = captured.cookieContainers.first;
            expect(
              cookieContainer.cookie,
              AuthorizationProviderTestData.cookieString,
            );
          } else {
            throw Exception("Authorization provider has wrong type!");
          }

          verify(cache.removeOperation(operationId));
        });

        test(
            "Then the call is propagated to the cached delegate and a JWT authorization provider is created.",
            () async {
          final operation = MockOutOfBandAuthenticationPlatformOperation();
          final operationId = CommonTestData.operationId;
          when(cache.getOperation(operationId)).thenReturn(operation);
          when(cache.removeOperation(operationId)).thenReturn(null);
          when(operation.onSuccess(any)).thenReturn(null);

          await channel.invokeMockMethod(
            methodName,
            OnSuccessTestData.correctArgumentsWithJwtProvider,
          );

          verify(cache.getOperation(operationId));
          var captured =
              verify(operation.onSuccess(captureAny)).captured.single;
          if (captured is JwtAuthorizationProvider) {
            expect(captured.jwt, AuthorizationProviderTestData.jwt);
          } else {
            throw Exception("Authorization provider has wrong type!");
          }

          verify(cache.removeOperation(operationId));
        });
      });

      group("When the operationId is missing", () {
        test("Then PlatformChannelException is thrown", () async {
          final operationId = CommonTestData.wrongId;
          when(cache.getOperation(operationId)).thenThrow(
            PlatformChannelException(
              error: PlatformChannelError.noOperationFoundError(
                operationId: operationId,
              ),
            ),
          );

          try {
            await channel.invokeMockMethod(
              methodName,
              OnSuccessTestData.wrongArguments,
            );
            fail('PlatformChannelException expected');
          } on PlatformException catch (e) {
            expect(
              e.message,
              CommonTestData.platformChannelExceptionMatcher,
            );
          } on Exception catch (_) {
            fail('PlatformException expected');
          }
          verify(cache.getOperation(operationId));
        });
      });
    });
  });
}
